@@ -1,4 +1,4 @@
-#' BayesFactor objects Parameters
+#' Parameters from BayesFactor objects
 #'
 #' Parameters of BayesFactor objects.
 #'
@@ -18,6 +18,12 @@
 #' @importFrom bayestestR bayesfactor_models
 #' @export
 model_parameters.BFBayesFactor <- function(model, centrality = "median", dispersion = FALSE, ci = 0.89, ci_method = "hdi", test = c("pd", "rope"), rope_range = "default", rope_ci = 0.89, priors = TRUE, ...) {
+
+  if (any(grepl("^Null", names(model@numerator)))) {
+    insight::print_color("Nothing to compute for point-null models.\nSee github.com/easystats/parameters/issues/226\n", "red")
+    return(NULL)
+  }
+
   out <- bayestestR::describe_posterior(model, centrality = centrality, dispersion = dispersion, ci = ci, ci_method = ci_method, test = test, rope_range = rope_range, rope_ci = rope_ci, priors = priors, ...)
 
   # Add components and effects columns
