@@ -180,3 +180,43 @@
 .safe_deparse <- function(string) {
   paste0(sapply(deparse(string, width.cutoff = 500), trimws, simplify = TRUE), collapse = " ")
 }
+
+
+
+#' @keywords internal
+.remove_columns <- function(data, variables) {
+  to_remove <- which(colnames(data) %in% variables)
+  if (length(to_remove))
+    data[, -to_remove, drop = FALSE]
+  else
+    data
+}
+
+
+
+
+#' @keywords internal
+.is_empty_object <- function(x) {
+  if (is.list(x)) {
+    x <- tryCatch({
+      .compact_list(x)
+    },
+    error = function(x) {
+      x
+    })
+  }
+  # this is an ugly fix because of ugly tibbles
+  if (inherits(x, c("tbl_df", "tbl"))) x <- as.data.frame(x)
+  x <- suppressWarnings(x[!is.na(x)])
+  length(x) == 0 || is.null(x)
+}
+
+
+
+
+#' @importFrom stats na.omit
+#' @keywords internal
+.n_unique <- function(x, na.rm = TRUE) {
+  if (isTRUE(na.rm)) x <- stats::na.omit(x)
+  length(unique(x))
+}
